[PATCH]: drivers/connector/cn_proc.c typos
From: David S. Miller (davem_at_davemloft.net)
Date: 11/30/05
- Previous message: Oleg Nesterov: "Re: [PATCH 1/9] timer locking optimization"
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]
Date: Wed, 30 Nov 2005 00:52:25 -0800 (PST) To: linux-kernel@vger.kernel.org
The parameter to put_cpu_var() is unreferenced by the implementation,
and the compiler doesn't try to comprehend comments, so this wouldn't
cause any problem, but if bugged me enough to post a fix :-)
Signed-off-by: David S. Miller <davem@davemloft.net>
diff --git a/drivers/connector/cn_proc.c b/drivers/connector/cn_proc.c
index fcdf0ff..7f59f79 100644
--- a/drivers/connector/cn_proc.c
+++ b/drivers/connector/cn_proc.c
@@ -34,14 +34,14 @@
static atomic_t proc_event_num_listeners = ATOMIC_INIT(0);
static struct cb_id cn_proc_event_id = { CN_IDX_PROC, CN_VAL_PROC };
/* proc_counts is used as the sequence number of the netlink message */
static DEFINE_PER_CPU(__u32, proc_event_counts) = { 0 };
static inline void get_seq(__u32 *ts, int *cpu)
{
*ts = get_cpu_var(proc_event_counts)++;
*cpu = smp_processor_id();
- put_cpu_var(proc_counts);
+ put_cpu_var(proc_event_counts);
}
void proc_fork_connector(struct task_struct *task)
-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/
- Previous message: Oleg Nesterov: "Re: [PATCH 1/9] timer locking optimization"
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]
Relevant Pages
- Re: [patch] time_after_eq fix
... If it is "a good compiler" or "a really good compiler", ... > More majordomo
info at http://vger.kernel.org/majordomo-info.html ... > Please read the FAQ at
http://www.tux.org/lkml/ ... send the line "unsubscribe linux-kernel" in ... (Linux-Kernel) - Re: What if?
@@ -34,14 +34,14 @@
static atomic_t proc_event_num_listeners = ATOMIC_INIT(0);
static struct cb_id cn_proc_event_id = { CN_IDX_PROC, CN_VAL_PROC };
-/* proc_counts is used as the sequence number of the netlink message */
+/* proc_event_counts is used as the sequence number of the netlink message */
static DEFINE_PER_CPU(__u32, proc_event_counts) = { 0 };
static inline void get_seq(__u32 *ts, int *cpu)
... So though FAQ answers my question, ... There was support to compile Linux using
g++ for a C compiler ... Rewriting Linux in C++ means fundamental redesign; ...
send the line "unsubscribe linux-kernel" in ... (Linux-Kernel) - Re: 2.6.5+BK compile error: binfmt_elf on sparc64
... >> At the first glance I can't see what's wrong here. ... > The compiler
is telling us that the condition is always false because a 32-bit ... send the line "unsubscribe
linux-kernel" in ... Please read the FAQ at http://www.tux.org/lkml/ ... (Linux-Kernel) - Re: [PATCH][2.6] constant_test_bit doesnt like my gcc
... On Thursday 16 October 2003 06:22, Zwane Mwaikambo wrote: ... Does your compiler
get this right? ... send the line "unsubscribe linux-kernel" in ... Please read
the FAQ at http://www.tux.org/lkml/ ... (Linux-Kernel) - Re: ZONE_PADDING wastes 4 bytes of the new cacheline
... >> peraphs we should add a check on the compiler and force people to use
... To unsubscribe from this list: send the line "unsubscribe linux-kernel" in the body
of a message to majordomo@vger.kernel.org More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/ ... (Linux-Kernel)